<?php

namespace Drupal\dpl;

use Drupal\consumers\Entity\Consumer;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Provides the controller for the preview page.
 */
class Controller implements ContainerInjectionInterface {

  /**
   * The consumer preview links.
   *
   * @var \Drupal\dpl\ConsumerPreviewLinks
   */
  protected $consumerPreviewLinks;

  /**
   * Controller constructor.
   * 
   * @param \Drupal\dpl\ConsumerPreviewLinks $consumerPreviewLinks
   *   The consumer preview links.
   */
  public function __construct(ConsumerPreviewLinks $consumerPreviewLinks) {
    $this->consumerPreviewLinks = $consumerPreviewLinks;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static($container->get('dpl.preview_links'));
  }

  /**
   * Controller for the preview page.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *
   * @return array
   *   The render array.
   */
  public function preview(Consumer $consumer, Request $request) {
    $url = $request->query->get('url');
    return [
      '#theme' => 'dpl_preview',
      '#attached' => [
        'library' => [
          'dpl/preview',
        ],
      ],
      '#url' => $url,
      '#entity_url' => $request->query->get('entity_url'),
      '#sizes' => $this->consumerPreviewLinks->getBrowserSizes($consumer),
    ];
  }

}
