<?php

namespace Drupal\dpl\Plugin\Deriver;

use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\dpl\ConsumerPreviewLinks;
use Drupal\consumers\Entity\Consumer;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides local tasks one for each preview links.
 */
class PreviewLinkLocalTaskDeriver extends DeriverBase implements ContainerDeriverInterface {

  use StringTranslationTrait;

  /**
   * The consumer preview links.
   *
   * @var \Drupal\dpl\ConsumerPreviewLinks
   */
  protected $consumerPreviewLinks;

  /**
   * Constructs a new LayoutBuilderLocalTaskDeriver.
   *
   * @param \Drupal\dpl\ConsumerPreviewLinks $consumer_preview_links
   *   The consumer preview links.
   */
  public function __construct(ConsumerPreviewLinks $consumer_preview_links) {
    $this->consumerPreviewLinks = $consumer_preview_links;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $container->get('dpl.preview_links')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    if (empty($this->derivatives)) {
      $definitions = [];
      foreach ($this->consumerPreviewLinks->getConsumsersWithPreviewLinks() as $consumer) {
        assert($consumer instanceof Consumer);
        $definition = $base_plugin_definition;
        $definition['consumer_id'] = $consumer->id();
        $definitions[$consumer->id()] = $definition;
      }
      $this->derivatives = $definitions;
    }

    return parent::getDerivativeDefinitions($base_plugin_definition);
  }
  

}
